@@ -1,8 +1,10 @@
+/* interface header; needs to be installed; FIXME rename? */
+
 #ifndef incl_PHP_GMP_INT_H
 #define incl_PHP_GMP_INT_H
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
 #include "php.h"
